@@ -251,6 +251,13 @@ class EfiVar:
         self.data = bytes(self.sigdb)
         self.update_time()
 
+    def sigdb_add_external_mgmt(self, guid):
+        if self.sigdb is None:
+            raise RuntimeError
+        self.sigdb.add_external_mgmt(guid)
+        self.data = bytes(self.sigdb)
+        self.update_time(initial_ts)
+
     def sigdb_add_dummy(self, guid):
         if self.sigdb is None:
             raise RuntimeError
@@ -450,6 +457,13 @@ class EfiVarList(collections.UserDict):
         var.sigdb_add_hash(guids.parse_str(owner),
                            bytes.fromhex(hashdata))
 
+    def add_external_mgmt(self, owner):
+        var = self.get('PK')
+        if not var:
+            var = self.create('PK')
+        logging.info('add external management guid to PK')
+        var.sigdb_add_external_mgmt(owner)
+
     def add_dummy_dbx(self, owner):
         var = self.get('dbx')
         if var:
@@ -469,10 +483,7 @@ class EfiVarList(collections.UserDict):
                                   ms_kek = 'all'):
         self.add_cert('PK', guid, cert, True)
         self.add_cert('KEK', guid, cert, True)
-        if ms_kek in ('2011', 'all'):
-            self.add_cert('KEK', guids.MicrosoftVendor, certs.MS_KEK_2011, False)
-        if ms_kek in ('2023', 'all'):
-            self.add_cert('KEK', guids.MicrosoftVendor, certs.MS_KEK_2023, False)
+        self.add_microsoft_kek_keys(ms_kek)
         self.add_dummy_dbx(guids.OvmfEnrollDefaultKeys)
 
     def enroll_platform_redhat(self, ms_kek = 'all'):
@@ -482,11 +493,23 @@ class EfiVarList(collections.UserDict):
         pk = certs.pk_generate(cn = name)
         self.enroll_platform_with_cert(pk.name, ms_kek = ms_kek)
 
+    def enroll_managed_platform(self, ms_kek = 'all'):
+        self.add_external_mgmt(guids.OvmfEnrollDefaultKeys)
+        self.add_microsoft_kek_keys(ms_kek)
+        self.add_dummy_dbx(guids.OvmfEnrollDefaultKeys)
+
     def add_microsoft_keys(self):
+        self.add_cert('db', guids.MicrosoftVendor, certs.MS_WIN_2011, False)
         self.add_cert('db', guids.MicrosoftVendor, certs.MS_WIN_2023, False)
         self.add_cert('db', guids.MicrosoftVendor, certs.MS_3RD_2011, False)
         self.add_cert('db', guids.MicrosoftVendor, certs.MS_3RD_2023, False)
 
+    def add_microsoft_kek_keys(self, ms_kek = 'all'):
+        if ms_kek in ('2011', 'all'):
+            self.add_cert('KEK', guids.MicrosoftVendor, certs.MS_KEK_2011, False)
+        if ms_kek in ('2023', 'all'):
+            self.add_cert('KEK', guids.MicrosoftVendor, certs.MS_KEK_2023, False)
+
     def add_distro_keys(self, distro):
         certlist = certs.DISTRO_CA.get(distro).get('certs')
         if not certlist:
